@@ -12,7 +12,7 @@ def test_install_via_installpkg(mock_venv, initproj, cmd):
             "tox.ini": """
                 [tox]
                 install_cmd = python -m -c 'print("ok")' -- {opts} {packages}'
-                """
+                """,
         },
     )
     fake_package = base.ensure(".tox", "dist", "pkg123-0.1.zip")
@@ -37,7 +37,7 @@ def test_sdist_latest(tmpdir, newconfig):
             distshare={}
             sdistsrc={{distshare}}/pkg123-*
     """.format(
-            distshare
+            distshare,
         ),
     )
     p = distshare.ensure("pkg123-1.4.5.zip")
@@ -56,8 +56,8 @@ def test_separate_sdist_no_sdistfile(cmd, initproj, tmpdir):
             [tox]
             distshare={}
         """.format(
-                distshare
-            )
+                distshare,
+            ),
         },
     )
     result = cmd("--sdistonly", "-e", "py")
@@ -73,7 +73,7 @@ def test_sdistonly(initproj, cmd):
         "example123",
         filedefs={
             "tox.ini": """
-    """
+    """,
         },
     )
     result = cmd("-v", "--sdistonly", "-e", "py")
@@ -115,7 +115,7 @@ def test_package_inject(initproj, cmd, monkeypatch, tmp_path):
             [testenv:py]
             passenv = PYTHONPATH
             commands = python -c 'import os; assert os.path.exists(os.environ["TOX_PACKAGE"])'
-        """
+        """,
         },
     )
     result = cmd("-q")
