@@ -17,7 +17,7 @@ def test_listenvs(cmd, initproj, monkeypatch):
 
         [testenv:docs]
         changedir = docs
-        """
+        """,
         },
     )
 
@@ -57,7 +57,7 @@ def test_listenvs_verbose_description(cmd, initproj):
         [testenv:docs]
         changedir = docs
         description = let me overwrite that
-        """
+        """,
         },
     )
     result = cmd("-lv")
@@ -85,7 +85,7 @@ def test_listenvs_all(cmd, initproj, monkeypatch):
 
         [testenv:docs]
         changedir = docs
-        """
+        """,
         },
     )
     result = cmd("-a")
@@ -121,7 +121,7 @@ def test_listenvs_all_verbose_description(cmd, initproj):
 
         [testenv:docs]
         changedir = docs
-        """
+        """,
         },
     )
     result = cmd("-av")
@@ -145,7 +145,7 @@ def test_listenvs_all_verbose_description_no_additional_environments(cmd, initpr
             "tox.ini": """
         [tox]
         envlist=py27,py36
-        """
+        """,
         },
     )
     result = cmd("-av")
@@ -168,7 +168,7 @@ def test_listenvs_packaging_excluded(cmd, initproj):
 
         [testenv:docs]
         changedir = docs
-        """
+        """,
         },
     )
     result = cmd("-a")
@@ -189,7 +189,7 @@ def test_listenvs_all_extra_definition_order_decreasing(cmd, initproj):
 
         [testenv:a]
         changedir = docs
-        """
+        """,
         },
     )
     result = cmd("-a")
@@ -210,9 +210,19 @@ def test_listenvs_all_extra_definition_order_increasing(cmd, initproj):
 
         [testenv:b]
         changedir = docs
-        """
+        """,
         },
     )
     result = cmd("-a")
     expected = ["py36", "a", "b"]
     assert result.outlines == expected
+
+
+def test_listenvs_without_default_envs(cmd, initproj):
+    """When running tox -l without any default envirinments, nothing happens."""
+    initproj(
+        "logsnada", filedefs={"tox.ini": ""},
+    )
+    result = cmd("-l")
+    assert result.ret == 0
+    assert result.out == ""
